==> Bundle-Git-LongList2-0.01.tar.gz: Bundle-Git-LongList2-0.01/lib/Bundle/Git/LongList2.pm <==
package Bundle::Git::LongList2;

use 5.005;
our $VERSION = '0.01';

1;

__END__

=head1 NAME

Bundle::Git::LongList1 - 
  Perl extension for installing all git modules

=head1 SYNOPSIS

  perl -MCPAN -e 'install Bundle::Git::LongList1'

=head1 DESCRIPTION

Bundle::Git::LongList1 is the first part of three parts.
  It's based on the long list as given by 01modules.index.
 
=head1 CONTENTS

Exporter

Carp

XSLoader

AutoLoader

parent

Encode

constant

Test

Text::Wrap

Pod::Escapes

Pod::Simple

File::Spec

Scalar::Util

Pod::Man

Data::Dumper

ExtUtils::MakeMaker

IO::Handle

Text::ParseWords

File::Path

Time::HiRes

base

Test::Harness

Test::More

File::Temp

IPC::Run3

Probe::Perl

IO::Pty

Test::Script

IPC::Run

System::Command

Pod::Usage

version

Getopt::Long

Git::Repository

JSON::PP

lib

CPAN::Meta::YAML

Parse::CPAN::Meta

Test::CPAN::Meta

Perl::OSType

Path::Class

Digest::base

Digest::SHA::PurePerl

Digest::SHA

CPAN::Meta

if

Path::Tiny

Pod::Escapes

Compress::Raw::Bzip2

Compress::Raw::Zlib

Compress::Zlib

Devel::Symdump

Pod::Parser

Pod::Coverage

Pod::Coverage::CountParents

Sub::Install

Data::OptList

ExtUtils::CBuilder

Params::Util

Sub::Exporter

Mixin::Linewise::Readers

Test::NoWarnings

Test::Tester

Test::Deep

Pod::Eventual::Simple

Pod::Coverage::TrustPod

Test::Pod

Test::Pod::Coverage

Git::FastExport

Git::Repository::Plugin::AUTOLOAD

Archive::Extract

Compress::Zlib

PerlIO::via::dynamic

IO::Digest

MooX::Types::MooseLike

Import::Into

indirect

bareword::filehandles

multidimensional

strictures

Class::Method::Modifiers

Role::Tiny

Moo

Config::GitLike

Number::Compare

Text::Glob

File::Find::Rule

Test::utf8

Data::Stream::Bulk

MooseX::StrictConstructor

Git::PurePerl

Test::Warnings

MooseX::Types

MooseX::Types::Common

MooseX::Types::Path::Class

Digest

String::RewritePrefix

MooseX::Storage

Any::Moose

File::Slurp

Tree::DAG_Node

Test::Warn

Const::Fast

Lexical::SealRequireHints

B::Hooks::OP::Annotation

Devel::Pragma

B::Hooks::OP::Check

ExtUtils::Depends

Sub::StrictDecl

DynaLoader::Functions

Devel::CallChecker

Lexical::Sub

Devel::CallParser

Devel::Declare

Devel::Declare::MethodInstaller::Simple

Meta::Builder

aliased

Exporter::Declare

Fennec::Lite

Mock::Quick

Test::Exception::LessClever

Devel::PPPort

Devel::CheckCompiler

Module::Build::XSUtil

Test::LeakTrace

experimental

Mouse

Class::Inspector

Clone

IO::String

Hook::LexWrap

Test::SubCalls

Digest::MD5

Test::Warnings

Test::Object

File::Remov

Data::Alias

Method::Signatures

File::Which

Locale::Maketext

ok

Sub::Uplevel

Test::Exception

Carp::Clan

namespace::clean

B::Hooks::EndOfScope

namespace::autoclean

Sub::Exporter::Progressive

Devel::GlobalDestruction

Sub::Name

Devel::StackTrace

Eval::Closure

Class::Load

Task::Weaken

MRO::Compat

Package::Stash::XS

Package::DeprecationManager

MooseX::Types::Moose

Class::Singleton

ExtUtils::Config

ExtUtils::ParseXS

Module::Load

ExtUtils::Helpers

File::Path

ExtUtils:::Install

TAP::Harness::Env

Module::Build::Tiny

Dist::CheckConflicts

Getopt::Long

Package::Stash

Class::Load

Capture::Tiny

Test::Output

Test::Taint

DateTime::TimeZone

List::MoreUtils

Attribute::Handlers

File::Temp

Module::Runtime

Module::Build

Test::Requires

Module::Implementation

Params::Validate

DateTime::Locale

Try::Tiny

Test::Fatal

Storable

DateTime

MooseX::Types::DateTime

Git::Gitalist

Git::PurePerl

Pod::Wordlist

Test::Compile

Test::EOL

Test::CPAN::Changes

Test::DistManifest

Test::CPAN::Meta::JSON

Perl::MinimumVersion

Test::MinimumVersion

Test::NoTabs

Test::Pod::LinkCheck

Test::Portability::Files

Test::Synopsis

Test::Version

Test::Vars

Test::Mojibake

File::ShareDir

File::ShareDir::Install

Path::FindDev

Path::IsDev

File::ShareDir::ProjectDistDir

Class::Tiny

Lingua::EN::Inflect

Pod::Spell

Test::Spelling

Class::Load::XS

MooseX::Role::Parameterized

Moose::Util::TypeConstraints

Test::TempDir

MooseX::Types::Stringlike

MooseX::Types::Path::Tiny

MooseX::ConfigFromFile

MooseX::SimpleConfig

MooseX::Getopt

Test::Moose::More

File::ChangeNotify

MooseX::MethodAttributes

Catalyst

MooseX::Role::WithOverloading

MooseX::AttributeHelpers

MooseX::Types

Specio::Declare

Moose::Util::TypeConstraints

Test::Able

B::Utils

Scope::Guard

B::OPCheck

invoker

true::VERSION

Sub::Identify

namespace::sweep

Method::Signatures::Simple

methods

Date::Parse

DateTime::Format::DateParse

Git::Hook::PostReceive

Text::CSV

Text::CSV::Slurp

Class::Data::Inheritable

Text::Balanced

HTML::Tagset

HTML::Entities

HTML::Element

Parse::RecDescent

CSS

MIME::Base64

URI

Text::Greeking

HTML::WikiConverter

HTML::Tree

HTML::WikiConverter::Markdown

Module::Pluggable

Class::Factory::Util

DateTime::Format::Strptime

DateTime::Format::Builder

DateTime::Format::Flexible

Clone

Module::Util

Term::ReadLine

boolean

Time::Piece

Test::MockTime

DateTime::Format::Natural

Test::Most

Set::Infinite

DateTime::Set

DateTime::Event::Recurrence

DateTime::Event::ICal

DateTime::Format::ICal

DateTimeX::Easy

WWW::RobotRules

HTTP::Cookies

Net::FTP

Net::HTTP

HTTP::Negotiate

File::Listing

HTML::Form

HTTP::Daemon

FCGI

CGI

HTTP::Server::Simple

Time::Local

HTTP::Date

IO::HTML

Encode::Locale

LWP::MediaTypes

HTTP::Status

WWW::Mechanize

Email::Address

Regexp::Common

Regexp::Common::Email::Address

HTML::TreeBuilder

Filter::Util::Call

pQuery

DateTime::Format::DateParse

IO::All

Test::Cukes

Test::Memory::Cycle

Quantum::Superpositions

Net::Redmine

Git::Release

Git::Sub

Git::Validate

Env::Path

IPC::Cmd

File::pushd

Sort::Versions

Git::Wrapper

Error

JSON

Mozilla::CA

Net::SSLeay

IO::Socket::SSL

LWP::Protocol::https

Crypt::SSLeay

LWP::UserAgent

REST::Client

Test::use::ok

Hash::Util::FieldHash::Compat

Data::Util

Net::Netrc

Gerrit::REST

Git::Hooks

Test::Carp

Test::Mock::Cmd

autodie

utf8::all

Getopt::Mini

Git::Open

Config::Tiny

PPIx::Regexp

String::Format

Perl::Tidy

Exception::Class

PPIx::Utilities::Statement

B::Keywords

Perl::Critic

IPC::System::Simple

Git::Hooks::PerlCritic

Mo

XS::Object::Magic

Git::XS

String::ShellQuote

File::Copy::Recursive

IO::Capture

Module::Find

Term::Encoding

Test::Classy

Log::Dump

Path::Extended

Git::Class

Term::Size

Term::ANSIScreen

Term::ANSIColor

Term::GentooFunctions

DBM::Deep

Git::SVNReplay

=head1 AUTHOR

Version 0.01 Kevin W. Henwood, <Khen1950fx@yahoo.com>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2014 by Kevin W. Henwood

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, or, at your option, any later 
version of Perl 5 you may have available.

=cut

==> Bundle-Git-LongList2-0.02.tar.gz: Bundle-Git-LongList2-0.02/lib/Bundle/Git/LongList2.pm <==
package Bundle::Git::LongList2;

use 5.005;
our $VERSION = '0.02';

1;

__END__

=head1 NAME

Bundle::Git::LongList2 - 
  Perl extension for installing all git modules

=head1 SYNOPSIS

  perl -MCPAN -e 'install Bundle::Git::LongList1'

=head1 DESCRIPTION

Bundle::Git::LongList2 is the second part of three parts.
  It's based on the long list as given by 01modules.index.
 
=head1 CONTENTS

Exporter

Carp

XSLoader

AutoLoader

parent

Encode

constant

Test

Text::Wrap

Pod::Escapes

Pod::Simple

File::Spec

Scalar::Util

Pod::Man

Data::Dumper

ExtUtils::MakeMaker

IO::Handle

Text::ParseWords

File::Path

Time::HiRes

base

Test::Harness

Test::More

File::Temp

IPC::Run3

Probe::Perl

IO::Pty

Test::Script

IPC::Run

System::Command

Pod::Usage

version

Getopt::Long

Git::Repository

JSON::PP

lib

CPAN::Meta::YAML

Parse::CPAN::Meta

Test::CPAN::Meta

Perl::OSType

Path::Class

Digest::base

Digest::SHA::PurePerl

Digest::SHA

CPAN::Meta

if

Path::Tiny

Pod::Escapes

Compress::Raw::Bzip2

Compress::Raw::Zlib

Compress::Zlib

Devel::Symdump

Pod::Parser

Pod::Coverage

Pod::Coverage::CountParents

Sub::Install

Data::OptList

ExtUtils::CBuilder

Params::Util

Sub::Exporter

Mixin::Linewise::Readers

Test::NoWarnings

Test::Tester

Test::Deep

Pod::Eventual::Simple

Pod::Coverage::TrustPod

Test::Pod

Test::Pod::Coverage

Git::FastExport

Git::Repository::Plugin::AUTOLOAD

Archive::Extract

Compress::Zlib

PerlIO::via::dynamic

IO::Digest

MooX::Types::MooseLike

Import::Into

indirect

bareword::filehandles

multidimensional

strictures

Class::Method::Modifiers

Role::Tiny

Moo

Config::GitLike

Number::Compare

Text::Glob

File::Find::Rule

Test::utf8

Data::Stream::Bulk

MooseX::StrictConstructor

Git::PurePerl

Test::Warnings

MooseX::Types

MooseX::Types::Common

MooseX::Types::Path::Class

Digest

String::RewritePrefix

MooseX::Storage

Any::Moose

File::Slurp

Tree::DAG_Node

Test::Warn

Const::Fast

Lexical::SealRequireHints

B::Hooks::OP::Annotation

Devel::Pragma

B::Hooks::OP::Check

ExtUtils::Depends

Sub::StrictDecl

DynaLoader::Functions

Devel::CallChecker

Lexical::Sub

Devel::CallParser

Devel::Declare

Devel::Declare::MethodInstaller::Simple

Meta::Builder

aliased

Exporter::Declare

Fennec::Lite

Mock::Quick

Test::Exception::LessClever

Devel::PPPort

Devel::CheckCompiler

Module::Build::XSUtil

Test::LeakTrace

experimental

Mouse

Class::Inspector

Clone

IO::String

Hook::LexWrap

Test::SubCalls

Digest::MD5

Test::Warnings

Test::Object

File::Remov

Data::Alias

Method::Signatures

File::Which

Locale::Maketext

ok

Sub::Uplevel

Test::Exception

Carp::Clan

namespace::clean

B::Hooks::EndOfScope

namespace::autoclean

Sub::Exporter::Progressive

Devel::GlobalDestruction

Sub::Name

Devel::StackTrace

Eval::Closure

Class::Load

Task::Weaken

MRO::Compat

Package::Stash::XS

Package::DeprecationManager

MooseX::Types::Moose

Class::Singleton

ExtUtils::Config

ExtUtils::ParseXS

Module::Load

ExtUtils::Helpers

File::Path

ExtUtils:::Install

TAP::Harness::Env

Module::Build::Tiny

Dist::CheckConflicts

Getopt::Long

Package::Stash

Class::Load

Capture::Tiny

Test::Output

Test::Taint

DateTime::TimeZone

List::MoreUtils

Attribute::Handlers

File::Temp

Module::Runtime

Module::Build

Test::Requires

Module::Implementation

Params::Validate

DateTime::Locale

Try::Tiny

Test::Fatal

Storable

DateTime

MooseX::Types::DateTime

Git::Gitalist

Git::PurePerl

Pod::Wordlist

Test::Compile

Test::EOL

Test::CPAN::Changes

Test::DistManifest

Test::CPAN::Meta::JSON

Perl::MinimumVersion

Test::MinimumVersion

Test::NoTabs

Test::Pod::LinkCheck

Test::Portability::Files

Test::Synopsis

Test::Version

Test::Vars

Test::Mojibake

File::ShareDir

File::ShareDir::Install

Path::FindDev

Path::IsDev

File::ShareDir::ProjectDistDir

Class::Tiny

Lingua::EN::Inflect

Pod::Spell

Test::Spelling

Class::Load::XS

MooseX::Role::Parameterized

Moose::Util::TypeConstraints

Test::TempDir

MooseX::Types::Stringlike

MooseX::Types::Path::Tiny

MooseX::ConfigFromFile

MooseX::SimpleConfig

MooseX::Getopt

Test::Moose::More

File::ChangeNotify

MooseX::MethodAttributes

Catalyst

MooseX::Role::WithOverloading

MooseX::AttributeHelpers

MooseX::Types

Specio::Declare

Moose::Util::TypeConstraints

Test::Able

B::Utils

Scope::Guard

B::OPCheck

invoker

true::VERSION

Sub::Identify

namespace::sweep

Method::Signatures::Simple

methods

Date::Parse

DateTime::Format::DateParse

Git::Hook::PostReceive

Text::CSV

Text::CSV::Slurp

Class::Data::Inheritable

Text::Balanced

HTML::Tagset

HTML::Entities

HTML::Element

Parse::RecDescent

CSS

MIME::Base64

URI

Text::Greeking

HTML::WikiConverter

HTML::Tree

HTML::WikiConverter::Markdown

Module::Pluggable

Class::Factory::Util

DateTime::Format::Strptime

DateTime::Format::Builder

DateTime::Format::Flexible

Clone

Module::Util

Term::ReadLine

boolean

Time::Piece

Test::MockTime

DateTime::Format::Natural

Test::Most

Set::Infinite

DateTime::Set

DateTime::Event::Recurrence

DateTime::Event::ICal

DateTime::Format::ICal

DateTimeX::Easy

WWW::RobotRules

HTTP::Cookies

Net::FTP

Net::HTTP

HTTP::Negotiate

File::Listing

HTML::Form

HTTP::Daemon

FCGI

CGI

HTTP::Server::Simple

Time::Local

HTTP::Date

IO::HTML

Encode::Locale

LWP::MediaTypes

HTTP::Status

WWW::Mechanize

Email::Address

Regexp::Common

Regexp::Common::Email::Address

HTML::TreeBuilder

Filter::Util::Call

pQuery

DateTime::Format::DateParse

IO::All

Test::Cukes

Test::Memory::Cycle

Quantum::Superpositions

Net::Redmine

Git::Release

Git::Sub

Git::Validate

Env::Path

IPC::Cmd

File::pushd

Sort::Versions

Git::Wrapper

Error

JSON

Mozilla::CA

Net::SSLeay

IO::Socket::SSL

LWP::Protocol::https

Crypt::SSLeay

LWP::UserAgent

REST::Client

Test::use::ok

Hash::Util::FieldHash::Compat

Data::Util

Net::Netrc

Gerrit::REST

Git::Hooks

Test::Carp

Test::Mock::Cmd

autodie

utf8::all

Getopt::Mini

Git::Open

Config::Tiny

PPIx::Regexp

String::Format

Perl::Tidy

Exception::Class

PPIx::Utilities::Statement

B::Keywords

Perl::Critic

IPC::System::Simple

Git::Hooks::PerlCritic

Mo

XS::Object::Magic

Git::XS

String::ShellQuote

File::Copy::Recursive

IO::Capture

Module::Find

Term::Encoding

Test::Classy

Log::Dump

Path::Extended

Git::Class

Term::Size

Term::ANSIScreen

Term::ANSIColor

Term::GentooFunctions

DBM::Deep

Git::SVNReplay

=head1 AUTHOR

Version 0.02 Kevin W. Henwood, <Khen1950fx@yahoo.com>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2014 by Kevin W. Henwood

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, or, at your option, any later 
version of Perl 5 you may have available.

=cut
